@@ -66,8 +66,7 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
         if args[1] is ProblemFormat.cpxlp:
             problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix = '.pyomo.lp')
             if instance:
-                instance.has_capability = capabilities
-                (problem_filename, varmap) = instance.write(filename=problem_filename,format=ProblemFormat.cpxlp)
+                (problem_filename, varmap) = instance.write(filename=problem_filename, format=ProblemFormat.cpxlp, solver_capability=capabilities)
                 return (problem_filename,),varmap # no map file is necessary
             else:
                 model = coopr.pyomo.scripting.pyomo2lp(['--save-model',problem_filename,args[2]])
@@ -76,7 +75,7 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
         elif args[1] in [ProblemFormat.mps, ProblemFormat.nl]:
             problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix = '.pyomo.nl')
             if instance:
-                (problem_filename, varmap) = instance.write(filename=problem_filename,format=ProblemFormat.nl)
+                (problem_filename, varmap) = instance.write(filename=problem_filename, format=ProblemFormat.nl, solver_capability=capabilities)
             else:
                 model = coopr.pyomo.scripting.pyomo2nl(['--save-model',problem_filename,args[2]])
                 problem_filename = model.filename
@@ -97,7 +96,7 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
         elif args[1] is ProblemFormat.osil:
             problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix='pyomo.osil')
             if instance:
-                (problem_filename, varmap) = instance.write(filename=problem_filename, format=ProblemFormat.osil)
+                (problem_filename, varmap) = instance.write(filename=problem_filename, format=ProblemFormat.osil, solver_capability=capabilities)
                 return (problem_filename,), None
             else:
                 msg = 'There is currently no script conversion available from\n'
