@@ -8,9 +8,10 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-import pyutilib.plugin.core
-pyutilib.plugin.core.PluginGlobals.push_env( 'coopr.opt' )
+import pyutilib.component.core
+pyutilib.component.core.PluginGlobals.push_env( 'coopr.opt' )
 
 import pyro
+import phpyro
 
-pyutilib.plugin.core.PluginGlobals.pop_env()
+pyutilib.component.core.PluginGlobals.pop_env()
